@@ -25,6 +25,7 @@ from django.db.models import Q
 
 # local project and app packages
 import djhcup_staging
+from djhcup_staging import tasks
 from djhcup_staging.models import State, DataSource, FileType, File, Column, ImportQueue, ImportBatch, StagingTable, StagingBatch, StagingQueue, ReferenceColumn
 from djhcup_staging.utils import misc, staging
 
@@ -45,51 +46,378 @@ def index(request):
     logger.debug('Index requested')
     
     link_list = [
-        {'display': 'Files',
-         'href': reverse('file_inventory'),
-         },
         {'display': 'Data source definitions',
-         'href': reverse('source_inventory'),
+         'href': reverse('ds_inv'),
          },
-        {'display': 'Batches',
-         'href': reverse('importbatch_inventory'),
+        {'display': 'Files',
+         'href': reverse('file_inv'),
+         },
+        {'display': 'Imports Batches',
+         'href': reverse('imb_inv'),
+         },
+        {'display': 'Staging Batches',
+         'href': reverse('stb_inv'),
+         },
+        {'display': 'Tables',
+         'href': reverse('tbl_inv'),
          },
         ]
-
-    #link_list.extend([{'display': 'Incomplete Batch: %s' % x, 'href': '/batches/%d/' % x.pk} for x in ImportBatch.objects.filter(complete__isnull=True)])
     
     context = {
         'title': 'Hachoir: Staging', 
         'links': link_list,
         }
-    template = 'djhcup_staging_base.html' #automagically looks in the templates directory for this app
+    template = 'stg_base.html' #automagically looks in the templates directory for this app
     return render(request, template, context)
 
 
-def source_inventory(request):
-    logger.debug('DataSource inventory requested')
-    sources = DataSource.objects.all()
-    sources_tl = sources.filter(parent__isnull=True)
-    sources_lst = [o for o in sources_tl]
+ALLOWED_OBJ_DETAIL = [
+    'DataSource',
+    'File',
+    'ImportBatch',
+    'StagingBatch',
+    'StagingTable',
+    'Column'
+]
 
-    context = {
-        'title': 'DataSource inventory', 
-        'counts': [
-            {'name': 'Total DataSources specified in database', 'value': sources.count()},
-            {'name': 'Top-level DataSources (without a parent DataSource)', 'value': sources_tl.count()},
-            ],
-        'objects': sources_lst,
-        'links': [],
+
+def obj_detail(request, obj_id, obj_type, msg_pt=[]): 
+    logger.debug('Detail requested for obj_type {t} and pk {pk}.'\
+        .format(t=obj_type, pk=obj_id))
+    
+    if obj_type not in ALLOWED_OBJ_DETAIL:
+        raise Exception("Invalid object type requested ({t})"\
+            .format(t=obj_type))
+    
+    if obj_type == 'DataSource':
+        source = DataSource.objects.get(pk=obj_id)
+        children = DataSource.objects.filter(parent=source)
+        files = File.objects.filter(file_type__source=source)
+        file_types = FileType.objects.filter(source=source)
+        import_tables = StagingTable.objects.filter(imported_via__file__file_type__source=source)
+        
+        context = {
+            'title': str(source),
+            'obj': source,
+            'children': children,
+            'files': {
+                'content': files.exclude(file_type__content_type__in=['LOAD']),
+                'load': files.filter(file_type__content_type__in=['LOAD']),
+            },
+            'file_types': file_types,
+            'import_tables': import_tables,
         }
+        template = 'stg_detail_ds.html'
     
-    if len(sources_lst) == 0:
-        # no sources found--offer to plug in the defaults
-        context['links'].append({
-            'display': 'Populate default source definitions for HCUP and Texas PUDF&rarr;',
-            'href': reverse('source_populate_defaults'),
-            })
+    elif obj_type == 'File':
+        f = File.objects.get(pk=obj_id)
+        context = {
+            'title': 'File #{pk}'.format(pk=f.pk),
+            'obj': f
+        }
+        template = 'stg_detail_f.html'
     
-    template = 'djhcup_staging_inventory.html' #automagically looks in the templates directory for this app
+    elif obj_type == 'ImportBatch':
+        ibatch = ImportBatch.objects.get(pk=obj_id)
+        enqueued = ibatch.importqueue_set.all()
+        context = {
+            'title': 'Details for %s' % ibatch,
+            'obj': ibatch,
+            'enqueued': enqueued,
+            'eta': sum([f.est_runtime for f in enqueued])
+        }
+        template = 'stg_detail_ibatch.html'
+    
+    elif obj_type == 'StagingBatch':
+        stbatch = StagingBatch.objects.get(pk=obj_id)
+        enqueued = stbatch.stagingqueue_set.all()
+        context = {
+            'title': 'Details for %s' % stbatch,
+            'obj': stbatch,
+            'enqueued': enqueued,
+        }
+        template = 'stg_detail_stbatch.html'
+    
+    elif obj_type == 'StagingTable':
+        tbl = StagingTable.objects.get(pk=obj_id)
+        context = {
+            'title': 'Details for %s' % tbl,
+            'obj': tbl,
+            'columns': tbl.column_set.all().order_by('name'),
+        }
+        template = 'stg_detail_tbl.html'
+    
+    elif obj_type == 'Column':
+        col = Column.objects.get(pk=obj_id)
+        context = {
+            'title': 'Details for %s' % col,
+            'obj': col,
+            'tbl': col.stg,
+        }
+        template = 'stg_detail_col.html'
+    
+    return render(request, template, context)
+
+
+def obj_inventory(request, obj_type, *args, **kwargs):    
+    logger.debug('Inventory requested for obj_type {t}.'\
+        .format(t=obj_type))
+    
+    if obj_type == 'DataSource':
+        sources = DataSource.objects.all()
+        sources_tl = sources.filter(parent__isnull=True)
+        sources_lst = [o for o in sources_tl]
+    
+        context = {
+            'title': 'DataSource Inventory', 
+            'counts': [
+                {'name': 'Total DataSources specified in database', 'value': sources.count()},
+                {'name': 'Top-level DataSources (without a parent DataSource)', 'value': sources_tl.count()},
+            ],
+            'objects': sources_lst,
+            'links': [],
+            }
+        
+        if len(sources_lst) == 0:
+            # no sources found--offer to plug in the defaults
+            context['links'].append({
+                'display': 'Populate default source definitions for HCUP and Texas PUDF&rarr;',
+                'href': reverse('source_populate_defaults'),
+                })
+        
+        template = 'stg_inv.html' #automagically looks in the templates directory for this app
+    
+    elif obj_type == 'File':
+        content = File.objects \
+            .exclude(file_type__content_type='LOAD') \
+            .order_by('state__abbreviation', 'year',
+                      'file_type__source__abbreviation', 'file_type')
+        loadfiles = File.objects \
+            .filter(file_type__content_type='LOAD') \
+            .order_by('state__abbreviation', 'year',
+                      'file_type__source__abbreviation', 'file_type')
+        
+        context = {
+            'title': "File Inventory"
+        }
+        
+        if ('state_abbr' in kwargs and
+            kwargs['state_abbr'] != 'all'):
+            st = kwargs['state_abbr']
+            context['state_abbr'] = st
+            content = content.filter(
+                state__abbreviation=st)
+            loadfiles = loadfiles.filter(
+                state__abbreviation=st)
+        else:
+            context['state_abbr'] = 'all'
+            
+        
+        if ('year' in kwargs and
+            kwargs['year'] != 'all'):
+            yr = kwargs['year']
+            context['year'] = yr
+            content = content.filter(
+                year=yr)
+            loadfiles = loadfiles.filter(
+                year=yr)
+        else:
+            context['year'] = 'all'
+        
+        context['content'] = content
+        context['loadfiles'] = loadfiles
+        
+        template = 'stg_inv_f.html'
+    
+    elif obj_type == 'ImportBatch':
+        imbs = ImportBatch.objects.all()
+        started = imbs.filter(start__isnull=False, complete__isnull=True)
+        not_started = imbs.filter(start__isnull=True)
+        completed = imbs.filter(start__isnull=False, complete__isnull=False)
+        context = {
+            'objects': imbs,
+            'started': started,
+            'not_started': not_started,
+            'completed': completed,
+            'title': "ImportBatch Inventory"
+        }
+        template = 'stg_inv_ibatch.html'
+    
+    elif obj_type == 'StagingBatch':
+        stb = StagingBatch.objects.all()
+        context = {
+            'objects': stb,
+            'title': "StagingBatch Inventory"
+        }
+        template = 'stg_inv.html'
+    
+    elif obj_type == 'StagingTable':
+        stt = StagingTable.objects.all()
+        context = {
+            'objects': stt,
+            'title': "StagingTable Inventory"
+        }
+        template = 'stg_inv.html'
+    
+    return render(request, template, context)
+
+
+def run_batch(request, obj_id, obj_type):
+    logger.debug('run_batch requested for obj_type {t} #{pk}'\
+        .format(t=obj_type, pk=obj_id))
+    
+    ALLOWED_BATCH_TYPES = [
+        'ImportBatch',
+        'StagingBatch',
+    ]
+    
+    if obj_type not in ALLOWED_BATCH_TYPES:
+        raise Exception("Requested batch type {t} not in allowed types: {a}"\
+            .format(t=obj_type, a=ALLOWED_BATCH_TYPES))
+    
+    if obj_type == 'ImportBatch':
+        logger.info('Attempting to call a Celery task for importing batch_id %i' % (int(batch_id)))
+        tresult = tasks.batch_import.delay(batch_id)
+        response = "ImportBatch has been dispatched to Celery in thread %s." % (tresult)
+        logger.info(response)
+        return obj_detail(request, obj_id, obj_type, msg_pt=[response])
+    
+    elif obj_type == 'StagingBatch':
+        logger.info('Attempting to call a Celery task for StagingBatch %i' % (int(batch_id)))
+        tresult = tasks.batch_stage.delay(batch_id)
+        response = "StagingBatch has been dispatched to Celery in thread %s." % (tresult)
+        logger.info(response)
+        return obj_detail(request, obj_id, obj_type, msg_pt=[response])
+
+
+def src_gen_master_table(request, source_id):
+    """For wide data, use all known loadfiles for source and generate one master table. For long data (or data which can be longed), make the corresponding fixed-style table.
+    """
+    
+    source = DataSource.objects.get(pk=source_id)
+    logger.info('Attempting to generate master table for %s' % source)
+    
+    cursor = cnxns[DJHCUP_DB_ENTRY].cursor()
+
+    # need later for table creation, but want the value to be based on the start of the process
+    now = datetime.datetime.utcnow().replace(tzinfo=utc).strftime("%Y%m%d%H%M%S")
+    db_table = "%s_%s" % (source.mr_descriptor, now)
+    pk_fields = []
+    index_fields = []
+    
+    # check to see whether this source has a LONG_MAPS entry, which would indicate it ought to be a long table
+    from pyhcup.parser import LONG_MAPS
+    if source.abbreviation in LONG_MAPS.keys():
+        logger.info('Match found in LONG_MAPS. This should be a fixed-style long table.')
+        create_sql = pyhcup.db.long_table_sql(db_table, str(source.abbreviation))
+        index_fields = ['KEY', 'VISITLINK', 'STATE', 'YEAR']
+    
+    else:
+        logger.info('No match found in LONG_MAPS. This should be a dynamically-generated wide table.')
+        
+        src_loadfiles = File.objects.filter(file_type__content_type__in=['LOAD'], file_type__source=source)
+        logger.info('Found %d loadfile records matching source' % len(src_loadfiles))
+        
+        meta_list = []
+        excluded = []
+        for lf in src_loadfiles:
+            try:
+                if lf.state.abbreviation.lower() == 'tx':
+                    # read the meta using the tx pudf stuff
+                    mdf = pyhcup.tx.meta_from_txt(lf.full_path)
+                    # mdf['state'] = 'tx'
+                    # mdf['year']
+                    augmented = pyhcup.meta.augment(mdf, dialect='pudf')
+                
+                else:
+                    # read the meta using the sas stuff
+                    mdf = pyhcup.sas.meta_from_sas(lf.full_path)
+                    augmented = pyhcup.meta.augment(mdf)
+                
+                # in any case, put in the meta list collection
+                meta_list.append(augmented)
+                
+            except:
+                # failed to read these in for some reason; held here for debug
+                excluded.append(lf.full_path)
+        
+        merged_meta = pyhcup.meta.merge(meta_list)
+        logger.info('Merged %d meta DataFrames successfully, with %d columns after de-duplication' % (len(meta_list), len(merged_meta)))
+        
+        constraints = ['NULL']
+        if source.top_level_source.abbreviation == 'HCUP':# redundant # and source.abbreviation not in LONG_MAPS.keys():
+            pk_fields = ['year', 'state', 'key']
+            index_fields += pk_fields
+        
+        create_sql = pyhcup.db.table_sql(merged_meta, db_table, pk_fields=pk_fields, ine=True, append_state=True, default_constraints=constraints)
+        
+    try:
+        cursor.execute(create_sql)
+        tx.commit(using=DJHCUP_DB_ENTRY)
+    except:
+        e = sys.exc_info()[0]
+        raise Exception("Failed to create master table with query %s (%s)" % (create_sql, e))
+    
+    logger.info('Created master table %s with on database %s' % (db_table, DJHCUP_DB_ENTRY))
+    
+    if index_fields != None:
+        try:
+            for col in index_fields:
+                index = pyhcup.db.index_sql(col, db_table)
+                cursor.execute(index)
+                tx.commit(using=DJHCUP_DB_ENTRY)
+                logger.info('Created index for column %s with on table %s' % (col, db_table))
+        except:
+            raise Exception("Failed to create indexes on table, particularly one that should have resulted from this query: %s" % index)
+    
+    table_record = StagingTable(source=source, name=db_table, database=DJHCUP_DB_ENTRY)
+    table_record.save()
+    logger.info('Saved master table details as StagingTable record %d' % table_record.pk)
+    
+    context = {
+        'title': 'Generate Master Table',
+        }
+    template = 'stg_base.html'
+    return render(request, template, context)
+
+
+def create_batch_from_unimported(request):
+    b = staging.unimported_batch()
+    
+    message = 'Created ImportBatch {pk} with {length} files' \
+        .format(pk=b.pk, length=len(b.importqueue_set.all()))
+    
+    return importbatch_inventory(request, msg_pass_through=[message])
+
+
+def create_batch_from_unprocessed(request):
+    batches = staging.unprocessed_batches()
+    
+    messages = [
+        "[StagingBatch {pk} ({s})]: {n} ({l} items)" \
+        .format(pk=b.pk, s=b.status, n=b.name, l=b.stagingqueue_set.all())
+        for b in batches
+    ]
+    
+    return importbatch_inventory(request, msg_pass_through=messages)
+
+
+def batch_reset_dead(request):
+    """Dispatches a celery task to reset interrupted ImportBatch objects and their associated ImportQueue objects.
+    """
+    from djhcup_staging import tasks
+    
+    logger.info('Attempting to call a Celery task for resetting dead batches')
+    tresult = tasks.reset_dead.delay()
+    
+    response = 'Reset request has been dispatched to Celery in thread %s; its completion state is %s' % (tresult, tresult.state)
+    logger.info(response)
+    
+    context = {
+        'title': 'Import Batch',
+        'response_messages': [{'content': response, 'type': 'info'}],
+        }
+    template = 'stg_base.html'
     return render(request, template, context)
 
 
@@ -129,67 +457,7 @@ def source_populate_defaults(request):
         'response_messages': response_messages,
         }
     
-    template = 'djhcup_staging_base.html'
-    return render(request, template, context)
-
-
-def source_detail(request, source_id):
-    logger.debug('DataSource %i detail requested' % int(source_id))
-    
-    source = DataSource.objects.get(pk=source_id)
-    children = DataSource.objects.filter(parent=source)
-    files = File.objects.filter(file_type__source=source)
-    file_types = FileType.objects.filter(source=source)
-    
-    import_tables = StagingTable.objects.filter(imported_via__file__file_type__source=source)
-    
-    context = {
-        'object_type': type(source),
-        'object': source,
-        'children': children,
-        'files': {
-                  'content': files.exclude(file_type__content_type__in=['LOAD']),
-                  'load': files.filter(file_type__content_type__in=['LOAD']),
-                 },'staging/files/'
-        'file_types': file_types,
-        'import_tables': import_tables,
-        }
-    
-    template = 'djhcup_staging_source_detail.html'
-    return render(request, template, context)
-
-
-def file_inventory(request, msg_pass_through=[]):
-    logger.debug('File inventory requested')
-    known_files = File.objects.all()
-    content_files = known_files.exclude(file_type__content_type__in=['LOAD'])
-    c_content_files = content_files.count()
-    c_unmatched_content_files = content_files.filter(loadfile__isnull=True).count()
-    c_matched_content_files = c_content_files - c_unmatched_content_files
-    
-    load_files = known_files.filter(file_type__content_type__in=['LOAD'])
-    c_load_files = load_files.count()
-
-    context = {
-        'title': 'File Inventory', 
-        'counts': [
-            {'name': 'Total Content Files', 'value': c_content_files},
-            {'name': 'Unmatched Content Files', 'value': c_unmatched_content_files},
-            {'name': 'Matched Content Files', 'value': c_matched_content_files},
-            {'name': 'Total Load Files', 'value': c_load_files},
-            ],
-        
-        'links':   [{
-                    'display': 'Discover files in DJHCUP_IMPORT_PATHS (%s)' % (DJHCUP_IMPORT_PATHS),
-                    'href': reverse('file_discover'),
-                    },
-                    {
-                    'display': 'Match discovered files',
-                    'href': reverse('file_match'),
-                    }],
-        'messages': msg_pass_through,
-        }
-    template = 'djhcup_staging_inventory.html'
+    template = 'stg_base.html'
     return render(request, template, context)
 
 
@@ -329,227 +597,3 @@ def file_match(request):
     
     return file_inventory(request, msg_pass_through=messages)
 
-
-def col_match(request):
-    """Attempts to match Column records from imported files with ReferenceColumn records
-    """
-    messages = []
-
-    unmatch_cols = Column.objects.filter(ref_col=None)
-    pass
-
-
-def src_gen_master_table(request, source_id):
-    """For wide data, use all known loadfiles for source and generate one master table. For long data (or data which can be longed), make the corresponding fixed-style table.
-    """
-    
-    source = DataSource.objects.get(pk=source_id)
-    logger.info('Attempting to generate master table for %s' % source)
-    
-    cursor = cnxns[DJHCUP_DB_ENTRY].cursor()
-
-    # need later for table creation, but want the value to be based on the start of the process
-    now = datetime.datetime.utcnow().replace(tzinfo=utc).strftime("%Y%m%d%H%M%S")
-    db_table = "%s_%s" % (source.mr_descriptor, now)
-    pk_fields = []
-    index_fields = []
-    
-    # check to see whether this source has a LONG_MAPS entry, which would indicate it ought to be a long table
-    from pyhcup.parser import LONG_MAPS
-    if source.abbreviation in LONG_MAPS.keys():
-        logger.info('Match found in LONG_MAPS. This should be a fixed-style long table.')
-        create_sql = pyhcup.db.long_table_sql(db_table, str(source.abbreviation))
-        index_fields = ['KEY', 'VISITLINK', 'STATE', 'YEAR']
-    
-    else:
-        logger.info('No match found in LONG_MAPS. This should be a dynamically-generated wide table.')
-        
-        src_loadfiles = File.objects.filter(file_type__content_type__in=['LOAD'], file_type__source=source)
-        logger.info('Found %d loadfile records matching source' % len(src_loadfiles))
-        
-        meta_list = []
-        excluded = []
-        for lf in src_loadfiles:
-            try:
-                if lf.state.abbreviation.lower() == 'tx':
-                    # read the meta using the tx pudf stuff
-                    mdf = pyhcup.tx.meta_from_txt(lf.full_path)
-                    # mdf['state'] = 'tx'
-                    # mdf['year']
-                    augmented = pyhcup.meta.augment(mdf, dialect='pudf')
-                
-                else:
-                    # read the meta using the sas stuff
-                    mdf = pyhcup.sas.meta_from_sas(lf.full_path)
-                    augmented = pyhcup.meta.augment(mdf)
-                
-                # in any case, put in the meta list collection
-                meta_list.append(augmented)
-                
-            except:
-                # failed to read these in for some reason; held here for debug
-                excluded.append(lf.full_path)
-        
-        merged_meta = pyhcup.meta.merge(meta_list)
-        logger.info('Merged %d meta DataFrames successfully, with %d columns after de-duplication' % (len(meta_list), len(merged_meta)))
-        
-        constraints = ['NULL']
-        if source.top_level_source.abbreviation == 'HCUP':# redundant # and source.abbreviation not in LONG_MAPS.keys():
-            pk_fields = ['year', 'state', 'key']
-            index_fields += pk_fields
-        
-        create_sql = pyhcup.db.table_sql(merged_meta, db_table, pk_fields=pk_fields, ine=True, append_state=True, default_constraints=constraints)
-        
-    try:
-        cursor.execute(create_sql)
-        tx.commit(using=DJHCUP_DB_ENTRY)
-    except:
-        e = sys.exc_info()[0]
-        raise Exception("Failed to create master table with query %s (%s)" % (create_sql, e))
-    
-    logger.info('Created master table %s with on database %s' % (db_table, DJHCUP_DB_ENTRY))
-    
-    if index_fields != None:
-        try:
-            for col in index_fields:
-                index = pyhcup.db.index_sql(col, db_table)
-                cursor.execute(index)
-                tx.commit(using=DJHCUP_DB_ENTRY)
-                logger.info('Created index for column %s with on table %s' % (col, db_table))
-        except:
-            raise Exception("Failed to create indexes on table, particularly one that should have resulted from this query: %s" % index)
-    
-    table_record = StagingTable(source=source, name=db_table, database=DJHCUP_DB_ENTRY)
-    table_record.save()
-    logger.info('Saved master table details as StagingTable record %d' % table_record.pk)
-    
-    context = {
-        'title': 'Generate Master Table',
-        }
-    template = 'djhcup_staging_base.html'
-    return render(request, template, context)
-
-
-def create_batch_from_unimported(request):
-    b = staging.unimported_batch()
-    
-    message = 'Created ImportBatch {pk} with {length} files' \
-        .format(pk=b.pk, length=len(b.importqueue_set.all()))
-    
-    return importbatch_inventory(request, msg_pass_through=[message])
-
-
-def create_batch_from_unprocessed(request):
-    batches = staging.unprocessed_batches()
-    
-    messages = [
-        "[StagingBatch {pk} ({s})]: {n} ({l} items)" \
-        .format(pk=b.pk, s=b.status, n=b.name, l=b.stagingqueue_set.all())
-        for b in batches
-    ]
-    
-    return importbatch_inventory(request, msg_pass_through=messages)
-
-
-def importbatch_inventory(request, msg_pass_through=[]):
-    logger.debug('Batch inventory requested')
-    messages = []
-    
-    batches = ImportBatch.objects.all()
-    completed = batches.filter(complete__isnull=False)
-    not_started = batches.filter(start__isnull=True)
-    started = batches.filter(start__isnull=False, complete__isnull=True)
-
-    context = {
-        'title': 'Batch inventory', 
-        'counts': [
-            {'name': 'Total batches', 'value': batches.count()},
-            {'name': 'Not started', 'value': not_started.count()},
-            {'name': 'Started', 'value': started.count()},
-            {'name': 'Completed', 'value': completed.count()},
-            ],
-        'not_started': not_started,
-        'started': started,
-        'completed': completed,
-        'messages': messages + msg_pass_through
-        }
-    template = 'djhcup_staging_batch_inventory.html' # automagically looks in the templates directory for this app
-    return render(request, template, context)
-
-
-def importbatch_detail(request, batch_id):
-    logger.debug('Batch %s detail requested' % batch_id)
-    batch = ImportBatch.objects.get(pk=batch_id)
-    enqueued_files = ImportQueue.objects.filter(batch=batch)
-    
-    context = {
-        'title': 'Details for %s' % batch,
-        'batch': batch,
-        'enqueued_files': enqueued_files,
-        }
-    if enqueued_files.count() > 0:
-        context['eta'] = sum([f.est_runtime for f in enqueued_files])
-    
-    template = 'djhcup_staging_batch_detail.html'
-    return render(request, template, context)
-
-
-def batch_import(request, batch_id):
-    """Schedules the indicated ImportBatch for import using Celery"""
-    logger.debug('ImportBatch %s requested' % batch_id)
-    
-    # import tasks for this module
-    from djhcup_staging import tasks
-    
-    logger.info('Attempting to call a Celery task for importing batch_id %i' % (int(batch_id)))
-    tresult = tasks.batch_import.delay(batch_id)
-    
-    response = "Batch has been dispatched to Celery in thread %s; its completion state is %s" % (tresult, tresult.state)
-    logger.info(response)
-    
-    context = {
-        'title': 'Import Batch',
-        'response_messages': [{'content': response, 'type': 'info'}],
-        }
-    template = 'djhcup_staging_base.html'
-    return render(request, template, context)
-
-
-def batch_stage(request, batch_id):
-    """Schedules the indicated StagingBatch for staging using Celery"""
-    logger.debug('StagingBatch %s requested' % batch_id)
-    
-    # import tasks for this module
-    from djhcup_staging import tasks
-    
-    logger.info('Attempting to call a Celery task for StagingBatch %i' % (int(batch_id)))
-    tresult = tasks.batch_stage.delay(batch_id)
-    
-    response = "StagingBatch has been dispatched to Celery in thread %s; its completion state is %s" % (tresult, tresult.state)
-    logger.info(response)
-    
-    context = {
-        'title': 'Import Batch',
-        'response_messages': [{'content': response, 'type': 'info'}],
-        }
-    template = 'djhcup_staging_base.html'
-    return render(request, template, context)
-
-
-def batch_reset_dead(request):
-    """Dispatches a celery task to reset interrupted ImportBatch objects and their associated ImportQueue objects.
-    """
-    from djhcup_staging import tasks
-    
-    logger.info('Attempting to call a Celery task for resetting dead batches')
-    tresult = tasks.reset_dead.delay()
-    
-    response = 'Reset request has been dispatched to Celery in thread %s; its completion state is %s' % (tresult, tresult.state)
-    logger.info(response)
-    
-    context = {
-        'title': 'Import Batch',
-        'response_messages': [{'content': response, 'type': 'info'}],
-        }
-    template = 'djhcup_staging_base.html'
-    return render(request, template, context)
